@@ -3,8 +3,9 @@
 /**
  +-----------------------------------------------------------------------+
  | This file is part of the Roundcube Webmail client                     |
- | Copyright (C) 2005-2012, The Roundcube Dev Team                       |
- | Copyright (C) 2011-2012, Kolab Systems AG                             |
+ |                                                                       |
+ | Copyright (C) The Roundcube Dev Team                                  |
+ | Copyright (C) Kolab Systems AG                                        |
  |                                                                       |
  | Licensed under the GNU General Public License version 3 or            |
  | any later version with exceptions for skins & plugins.                |
@@ -82,8 +83,6 @@ class rcube_image
                 'channels' => $channels,
             );
         }
-
-        return null;
     }
 
     /**
@@ -256,9 +255,9 @@ class rcube_image
                 imagecopyresampled($new_image, $image, 0, 0, 0, 0, $width, $height, $props['width'], $props['height']);
                 $image = $new_image;
 
-                // fix rotation of image if EXIF data exists and specifies rotation (GD strips the EXIF data)
+                // fix orientation of image if EXIF data exists and specifies orientation (GD strips the EXIF data)
                 if ($this->image_file && $type == 'jpg' && function_exists('exif_read_data')) {
-                    $exif = exif_read_data($this->image_file);
+                    $exif = @exif_read_data($this->image_file);
                     if ($exif && $exif['Orientation']) {
                         switch ($exif['Orientation']) {
                             case 3:
@@ -324,7 +323,7 @@ class rcube_image
             $p['out']  = $filename;
             $p['type'] = self::$extensions[$type];
 
-            $result = rcube::exec($convert . ' 2>&1 -colorspace sRGB -strip -quality 75 {in} {type}:{out}', $p);
+            $result = rcube::exec($convert . ' 2>&1 -colorspace sRGB -strip -flatten -quality 75 {in} {type}:{out}', $p);
 
             if ($result === '') {
                 chmod($filename, 0600);
@@ -396,7 +395,9 @@ class rcube_image
     }
 
     /**
-     * Checks if image format conversion is supported
+     * Checks if image format conversion is supported (for specified mimetype).
+     *
+     * @param string $mimetype Mimetype name
      *
      * @return boolean True if specified format can be converted to another format
      */
@@ -442,6 +443,10 @@ class rcube_image
 
     /**
      * Check if we have enough memory to load specified image
+     *
+     * @param array Hash array with image props like channels, width, height
+     *
+     * @return bool True if there's enough memory to process the image, False otherwise
      */
     private function mem_check($props)
     {
